@@ -3,12 +3,11 @@ use warnings;
 
 package Pod::Weaver::PluginBundle::ARJONES;
 {
-  $Pod::Weaver::PluginBundle::ARJONES::VERSION = '1.133170';
+  $Pod::Weaver::PluginBundle::ARJONES::VERSION = '1.133200';
 }
 
 # ABSTRACT: ARJONES's default Pod::Weaver config
 
-use Pod::Weaver::Plugin::Encoding ();
 use Pod::Weaver::Section::Contributors 0.001 ();
 
 
@@ -46,7 +45,7 @@ sub mvp_bundle_config {
 
     push @plugins,
       (
-        [ '@ARJONES/Encoding',  _exp('-Encoding'), {} ],
+        [ '@ARJONES/SingleEncoding',  _exp('-SingleEncoding'), {} ],
         [ '@ARJONES/Leftovers', _exp('Leftovers'), {} ],
         [ '@ARJONES/postlude', _exp('Region'),  { region_name => 'postlude' } ],
         [ '@ARJONES/Authors',  _exp('Authors'), {} ],
@@ -72,7 +71,7 @@ Pod::Weaver::PluginBundle::ARJONES - ARJONES's default Pod::Weaver config
 
 =head1 VERSION
 
-version 1.133170
+version 1.133200
 
 =head1 DESCRIPTION
 
